==> ai-search-spm-1.0.10.tgz: package/es/index.js <==
import _extends from "@babel/runtime/helpers/extends";

function _createForOfIteratorHelperLoose(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; return function () { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } it = o[Symbol.iterator](); return it.next.bind(it); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

import queryString from 'query-string';
import { setSession, getSession, formatParams } from './utils';

var Spm = /*#__PURE__*/function () {
  function Spm(props) {
    this.appType = void 0;
    this.pageSessionName = void 0;
    this.moduleSessionName = void 0;
    this.eventSessionName = void 0;
    this.fromApp = void 0;
    this.onPageLoad = void 0;
    this.onEventListener = void 0;
    this.listenerEvents = void 0;
    this.isHash = void 0;
    this.fromParams = void 0;
    this.headerCustomPrefix = void 0;
    this.spmPrefix = void 0;
    this.appType = props.appType;
    this.spmPrefix = props.spmPrefix || 'data-spm-';
    this.pageSessionName = props.pageSessionName || 'spmPage';
    this.moduleSessionName = props.moduleSessionName || 'spmModule';
    this.eventSessionName = props.eventSessionName || 'spmEvent';
    this.fromApp = props.fromApp || 'from_app';
    this.headerCustomPrefix = props.headerCustomPrefix || 'log-';
    this.onPageLoad = props.onPageLoad;
    this.onEventListener = props.onEventListener;
    this.listenerEvents = props.listenerEvents || ['click', 'keyup'];
    this.isHash = props.isHash || false;
    this.fromParams = props.fromParams || false; // 执行初始化

    this.init();
  }
  /**
   * 获取所属模块或者页面的spm
   * @param dom 触发事件的dom
   * @param spmType 页面、模块、事件的spm属性名
   */


  var _proto = Spm.prototype;

  _proto.findSpm = function findSpm(dom, spmType) {
    var domGet = dom;
    var spmData = '';
    var spmDom = domGet;

    while (domGet) {
      var spmValue = domGet && domGet.getAttribute(spmType);

      if (spmValue) {
        spmData = spmValue;
        spmDom = domGet;
        domGet = null;
      }

      domGet && (domGet = domGet.parentElement);
    }

    return {
      spmDom: spmDom,
      spmData: spmData
    };
  }
  /**
   * 获取自定义埋点数据
   * @param dom 点击的dom
   */
  ;

  _proto.getCustomSpm = function getCustomSpm(dom) {
    var params = {};
    var domGet = dom;

    while (domGet) {
      var attrs = domGet.getAttributeNames();
      var eventSpm = this.spmPrefix + "event";
      var moduleSpm = this.spmPrefix + "module";
      var pageSpm = this.spmPrefix + "page";

      for (var _iterator = _createForOfIteratorHelperLoose(attrs), _step; !(_step = _iterator()).done;) {
        var attr = _step.value;

        if (attr.startsWith(this.spmPrefix, 0) && attr !== moduleSpm && attr !== pageSpm && attr !== eventSpm) {
          params[attr] = domGet && domGet.getAttribute(attr);
        }
      }

      domGet && (domGet = domGet.parentElement);
    }

    return params;
  };

  _proto.location = function location(prop) {
    var _window = window,
        location = _window.location;

    if (this.isHash && prop === 'hash') {
      var hash = location.hash;
      location.hash.replace(/^#\/(.*)\?/, function (str, $1) {
        hash = "#/" + $1;
        return '';
      });
      return hash;
    }

    return location[prop];
  };

  _proto.pageLoad = function pageLoad(page) {
    // 获取应用埋点信息
    var urlParams = queryString.parse(this.location('search'));
    var fromApp = urlParams[this.fromApp]; // 获取缓存内的page、module、event埋点数据

    var fromPage = getSession('fromPage');
    var fromModule = getSession('fromModule');
    var fromEvent = getSession('fromEvent'); // 删除url中的三方应用信息

    urlParams[this.fromApp] = undefined;
    var query = queryString.stringify(urlParams);
    query = query ? "?" + query : query;
    window.history.replaceState(null, '', "" + this.location('origin') + this.location('pathname') + this.location('hash') + query); // 删除session内from的数据

    setSession('fromPage');
    setSession('fromModule');
    setSession('fromEvent'); // set当前页面session

    setSession(this.moduleSessionName);
    setSession(this.eventSessionName);
    setSession(this.pageSessionName, "" + page);
    var params = formatParams(this, {
      app: this.appType,
      page: page,
      fromApp: fromApp,
      fromPage: fromPage,
      fromModule: fromModule,
      fromEvent: fromEvent
    });
    params[this.headerCustomPrefix + "visit-type"] = 'page';
    this.onPageLoad && this.onPageLoad(_extends({}, params));
  }
  /**
   * 埋点初始化
   */
  ;

  _proto.init = function init() {
    var _this = this;

    // 第一次加载页面
    window.onload = function () {
      // 获取页面埋点信息
      var pageDom = document.querySelector("[" + _this.spmPrefix + "page]");
      var page = pageDom && pageDom.getAttribute(_this.spmPrefix + "page");

      if (page) {
        _this.pageLoad(page);
      }
    }; // 路由更新，页面渲染，session处理


    window.addEventListener('history', function () {
      if (history.state && history.state.key) {
        var oldPageName = getSession(_this.pageSessionName);
        var itv = setInterval(function () {
          var pageDom = document.querySelector("[" + _this.spmPrefix + "page]");
          var page = pageDom && pageDom.getAttribute(_this.spmPrefix + "page");

          if (page && oldPageName !== page) {
            clearInterval(itv);

            _this.pageLoad(page);
          }
        }, 0);
      }
    }); // 监听页面事件

    this.listenerEvents.forEach(function (event) {
      document.addEventListener(event, function (e) {
        var dom = e.target;
        var page = getSession(_this.pageSessionName);

        if (!dom || !page) {
          return;
        }

        var spmEventObj = _this.findSpm(dom, _this.spmPrefix + "event");

        var spmEvent = spmEventObj.spmData;
        if (!spmEventObj.spmDom || !spmEvent) return;

        var spmModuleObj = _this.findSpm(spmEventObj.spmDom || dom, _this.spmPrefix + "module");

        var spmModule = spmModuleObj.spmData; // 如果spmModule没有，则直接用spmEvent

        if (!spmModule) return;

        var customParams = _this.getCustomSpm(spmEventObj.spmDom);

        setSession(_this.eventSessionName, spmEvent);
        setSession(_this.moduleSessionName, spmModule);
        var params = formatParams(_this, {
          app: _this.appType,
          page: page,
          module: spmModule,
          event: spmEvent
        }, customParams);
        params[_this.headerCustomPrefix + "visit-type"] = 'event';
        setSession('fromPage', page);
        setSession('fromModule', spmModule);
        setSession('fromEvent', spmEvent);

        if (spmEvent) {
          _this.onEventListener && _this.onEventListener(params);
        }
      });
    });
  };

  return Spm;
}();

export { Spm as default };

==> ai-search-spm-1.1.1.tgz: package/es/index.js <==
import _extends from "@babel/runtime/helpers/extends";

function _createForOfIteratorHelperLoose(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; return function () { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } it = o[Symbol.iterator](); return it.next.bind(it); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

import queryString from 'query-string';
import { setSession, getSession, formatParams } from './utils';

var Spm = /*#__PURE__*/function () {
  function Spm(props) {
    this.appType = void 0;
    this.pageSessionName = void 0;
    this.moduleSessionName = void 0;
    this.eventSessionName = void 0;
    this.fromApp = void 0;
    this.onPageLoad = void 0;
    this.onEventListener = void 0;
    this.listenerEvents = void 0;
    this.isHash = void 0;
    this.fromParams = void 0;
    this.headerCustomPrefix = void 0;
    this.spmPrefix = void 0;
    this.pageSpmPrefix = void 0;
    this.appType = props.appType;
    this.spmPrefix = props.spmPrefix || 'data-spm-';
    this.pageSpmPrefix = props.pageSpmPrefix || 'page-spm-';
    this.pageSessionName = props.pageSessionName || 'spmPage';
    this.moduleSessionName = props.moduleSessionName || 'spmModule';
    this.eventSessionName = props.eventSessionName || 'spmEvent';
    this.fromApp = props.fromApp || 'from_app';
    this.headerCustomPrefix = props.headerCustomPrefix || 'log-';
    this.onPageLoad = props.onPageLoad;
    this.onEventListener = props.onEventListener;
    this.listenerEvents = props.listenerEvents || ['click', 'keyup'];
    this.isHash = props.isHash || false;
    this.fromParams = props.fromParams || false; // 执行初始化

    this.init();
  }
  /**
   * 获取所属模块或者页面的spm
   * @param dom 触发事件的dom
   * @param spmType 页面、模块、事件的spm属性名
   */


  var _proto = Spm.prototype;

  _proto.findSpm = function findSpm(dom, spmType) {
    var domGet = dom;
    var spmData = '';
    var spmDom = domGet;

    while (domGet) {
      var spmValue = domGet && domGet.getAttribute(spmType);

      if (spmValue) {
        spmData = spmValue;
        spmDom = domGet;
        domGet = null;
      }

      domGet && (domGet = domGet.parentElement);
    }

    return {
      spmDom: spmDom,
      spmData: spmData
    };
  }
  /**
   * 获取event自定义埋点数据
   * @param dom 点击的dom
   */
  ;

  _proto.getEventCS = function getEventCS(dom) {
    var params = {};
    var domGet = dom;

    while (domGet) {
      var attrs = domGet.getAttributeNames();
      var eventSpm = this.spmPrefix + "event";
      var moduleSpm = this.spmPrefix + "module";
      var pageSpm = this.spmPrefix + "page";

      for (var _iterator = _createForOfIteratorHelperLoose(attrs), _step; !(_step = _iterator()).done;) {
        var attr = _step.value;

        if (attr.startsWith(this.spmPrefix, 0) && attr !== moduleSpm && attr !== pageSpm && attr !== eventSpm) {
          var _key = attr.replace(this.spmPrefix, this.headerCustomPrefix);

          params[_key] = domGet && domGet.getAttribute(attr);
        }
      }

      domGet && (domGet = domGet.parentElement);
    }

    return params;
  }
  /**
   * 获取page自定义埋点数据
   */
  ;

  _proto.getPageCS = function getPageCS() {
    var params = {};
    var doms = document.getElementsByTagName('*');

    for (var _iterator2 = _createForOfIteratorHelperLoose(doms), _step2; !(_step2 = _iterator2()).done;) {
      var dom = _step2.value;
      var attrs = dom.getAttributeNames();

      for (var _iterator3 = _createForOfIteratorHelperLoose(attrs), _step3; !(_step3 = _iterator3()).done;) {
        var attr = _step3.value;

        if (attr.startsWith(this.pageSpmPrefix, 0)) {
          var _key2 = attr.replace(this.pageSpmPrefix, this.headerCustomPrefix + "page-");

          params[_key2] = dom && dom.getAttribute(attr);
        }
      }
    }

    return params;
  };

  _proto.location = function location(prop) {
    var _window = window,
        location = _window.location;

    if (this.isHash && prop === 'hash') {
      var hash = location.hash;
      location.hash.replace(/^#\/(.*)\?/, function (str, $1) {
        hash = "#/" + $1;
        return '';
      });
      return hash;
    }

    return location[prop];
  };

  _proto.pageLoad = function pageLoad(page) {
    // 获取应用埋点信息
    var urlParams = queryString.parse(this.location('search'));
    var fromApp = urlParams[this.fromApp]; // 获取缓存内的page、module、event埋点数据

    var fromPage = getSession('fromPage');
    var fromModule = getSession('fromModule');
    var fromEvent = getSession('fromEvent'); // 删除url中的三方应用信息
    // urlParams[this.fromApp] = undefined;
    // let query = queryString.stringify(urlParams);
    // query = query ? `?${query}` : query;
    // const url = `${this.location('origin')}${this.location('pathname')}${this.location('hash')}${query}`;
    // window.history.replaceState(null, '', url);
    // 删除session内from的数据

    setSession('fromPage');
    setSession('fromModule');
    setSession('fromEvent'); // set当前页面session

    setSession(this.moduleSessionName);
    setSession(this.eventSessionName);
    setSession(this.pageSessionName, "" + page);
    var customParams = this.getPageCS();
    var params = formatParams(this, {
      app: this.appType,
      page: page,
      fromApp: fromApp,
      fromPage: fromPage,
      fromModule: fromModule,
      fromEvent: fromEvent
    }, customParams);
    params[this.headerCustomPrefix + "visit-type"] = 'page';
    this.onPageLoad && this.onPageLoad(_extends({}, params));
  }
  /**
   * 埋点初始化
   */
  ;

  _proto.init = function init() {
    var _this = this;

    // 第一次加载页面
    window.onload = function () {
      // 获取页面埋点信息
      var pageDom = document.querySelector("[" + _this.spmPrefix + "page]");
      var page = pageDom && pageDom.getAttribute(_this.spmPrefix + "page");

      if (page) {
        _this.pageLoad(page);
      }
    }; // 路由更新，页面渲染，session处理


    window.addEventListener('history', function () {
      if (history.state && history.state.key) {
        var oldPageName = getSession(_this.pageSessionName);
        var itv = setInterval(function () {
          var pageDom = document.querySelector("[" + _this.spmPrefix + "page]");
          var page = pageDom && pageDom.getAttribute(_this.spmPrefix + "page");

          if (page && oldPageName !== page) {
            clearInterval(itv);

            _this.pageLoad(page);
          }
        }, 0);
      }
    }); // 监听页面事件

    this.listenerEvents.forEach(function (event) {
      document.addEventListener(event, function (e) {
        var dom = e.target;
        var page = getSession(_this.pageSessionName);

        if (!dom || !page) {
          return;
        }

        var spmEventObj = _this.findSpm(dom, _this.spmPrefix + "event");

        var spmEvent = spmEventObj.spmData;
        if (!spmEventObj.spmDom || !spmEvent) return;

        var spmModuleObj = _this.findSpm(spmEventObj.spmDom || dom, _this.spmPrefix + "module");

        var spmModule = spmModuleObj.spmData; // 如果spmModule没有，则直接用spmEvent

        if (!spmModule) return;

        var customParams = _this.getEventCS(spmEventObj.spmDom);

        setSession(_this.eventSessionName, spmEvent);
        setSession(_this.moduleSessionName, spmModule);
        var params = formatParams(_this, {
          app: _this.appType,
          page: page,
          module: spmModule,
          event: spmEvent
        }, customParams);
        params[_this.headerCustomPrefix + "visit-type"] = 'event';
        setSession('fromPage', page);
        setSession('fromModule', spmModule);
        setSession('fromEvent', spmEvent);

        if (spmEvent) {
          _this.onEventListener && _this.onEventListener(params);
        }
      });
    });
  };

  return Spm;
}();

export { Spm as default };
